@@ -4,9 +4,9 @@ from pathlib import Path
 
 from ultralytics import yolo  # noqa
 from ultralytics.nn.tasks import ClassificationModel, DetectionModel, SegmentationModel, attempt_load_one_weight
-from ultralytics.yolo.configs import get_config
+from ultralytics.yolo.cfg import get_cfg
 from ultralytics.yolo.engine.exporter import Exporter
-from ultralytics.yolo.utils import DEFAULT_CFG_PATH, LOGGER, yaml_load
+from ultralytics.yolo.utils import DEFAULT_CFG, LOGGER, yaml_load
 from ultralytics.yolo.utils.checks import check_yaml
 from ultralytics.yolo.utils.torch_utils import guess_task_from_head, smart_inference_mode
 
@@ -136,7 +136,7 @@ class YOLO:
             self.predictor = self.PredictorClass(overrides=overrides)
             self.predictor.setup_model(model=self.model)
         else:  # only update args if predictor is already setup
-            self.predictor.args = get_config(self.predictor.args, overrides)
+            self.predictor.args = get_cfg(self.predictor.args, overrides)
         return self.predictor(source=source, stream=stream, verbose=verbose)
 
     @smart_inference_mode()
@@ -151,7 +151,7 @@ class YOLO:
         overrides = self.overrides.copy()
         overrides.update(kwargs)
         overrides["mode"] = "val"
-        args = get_config(config=DEFAULT_CFG_PATH, overrides=overrides)
+        args = get_cfg(cfg=DEFAULT_CFG, overrides=overrides)
         args.data = data or args.data
         args.task = self.task
 
@@ -169,10 +169,9 @@ class YOLO:
 
         overrides = self.overrides.copy()
         overrides.update(kwargs)
-        args = get_config(config=DEFAULT_CFG_PATH, overrides=overrides)
+        args = get_cfg(cfg=DEFAULT_CFG, overrides=overrides)
         args.task = self.task
 
-        print(args)
         exporter = Exporter(overrides=args)
         exporter(model=self.model)
 
@@ -181,8 +180,7 @@ class YOLO:
         Trains the model on a given dataset.
 
         Args:
-            **kwargs (Any): Any number of arguments representing the training configuration. List of all args can be found in 'config' section.
-                            You can pass all arguments as a yaml file in `cfg`. Other args are ignored if `cfg` file is passed
+            **kwargs (Any): Any number of arguments representing the training configuration.
         """
         overrides = self.overrides.copy()
         overrides.update(kwargs)
@@ -192,7 +190,7 @@ class YOLO:
         overrides["task"] = self.task
         overrides["mode"] = "train"
         if not overrides.get("data"):
-            raise AttributeError("dataset not provided! Please define `data` in config.yaml or pass as an argument.")
+            raise AttributeError("Dataset required but missing, i.e. pass 'data=coco128.yaml'")
         if overrides.get("resume"):
             overrides["resume"] = self.ckpt_path
 
@@ -201,7 +199,7 @@ class YOLO:
             self.trainer.model = self.trainer.get_model(weights=self.model if self.ckpt else None, cfg=self.model.yaml)
             self.model = self.trainer.model
         self.trainer.train()
-        # update model and configs after training
+        # update model and cfg after training
         self.model, _ = attempt_load_one_weight(str(self.trainer.best))
         self.overrides = self.model.args
 
@@ -223,6 +221,13 @@ class YOLO:
 
         return model_class, trainer_class, validator_class, predictor_class
 
+    @property
+    def names(self):
+        """
+         Returns class names of the loaded model.
+        """
+        return self.model.names
+
     @staticmethod
     def _reset_ckpt_args(args):
         args.pop("project", None)
